@@ -32,8 +32,6 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
-#include "egg-debug.h"
-
 #include "up-polkit.h"
 #include "up-device-list.h"
 #include "up-device.h"
@@ -53,6 +51,8 @@ enum
 	PROP_ON_LOW_BATTERY,
 	PROP_LID_IS_CLOSED,
 	PROP_LID_IS_PRESENT,
+	PROP_LID_FORCE_SLEEP,
+	PROP_IS_DOCKED,
 	PROP_LAST
 };
 
@@ -80,6 +80,8 @@ struct UpDaemonPrivate
 	gboolean		 on_low_battery;
 	gboolean		 lid_is_closed;
 	gboolean		 lid_is_present;
+	gboolean		 lid_force_sleep;
+	gboolean		 is_docked;
 	gboolean		 kernel_can_suspend;
 	gboolean		 kernel_can_hibernate;
 	gboolean		 hibernate_has_encrypted_swap;
@@ -238,13 +240,13 @@ up_daemon_set_powersave (UpDaemon *daemon, gboolean powersave)
 	/* run script */
 	command = up_backend_get_powersave_command (daemon->priv->backend, powersave);
 	if (command == NULL) {
-		egg_warning ("no powersave command set");
+		g_warning ("no powersave command set");
 		goto out;
 	}
-	egg_debug ("excuting command: %s", command);
+	g_debug ("excuting command: %s", command);
 	ret = g_spawn_command_line_async (command, &error);
 	if (!ret) {
-		egg_warning ("failed to run script: %s", error->message);
+		g_warning ("failed to run script: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -323,6 +325,7 @@ up_daemon_about_to_sleep (UpDaemon *daemon, DBusGMethodInvocation *context)
 				     UP_DAEMON_ERROR_GENERAL,
 				     "Sleep has already been requested and is pending");
 		dbus_g_method_return_error (context, error);
+		g_error_free (error);
 		goto out;
 	}
 
@@ -335,7 +338,7 @@ up_daemon_about_to_sleep (UpDaemon *daemon, DBusGMethodInvocation *context)
 		goto out;
 
 	/* we've told the clients we're going down */
-	egg_debug ("emitting sleeping");
+	g_debug ("emitting sleeping");
 	g_signal_emit (daemon, signals[SIGNAL_SLEEPING], 0);
 	g_timer_start (priv->about_to_sleep_timer);
 	daemon->priv->sent_sleeping_signal = TRUE;
@@ -376,11 +379,12 @@ up_daemon_deferred_sleep_cb (UpDaemonDeferredSleep *sleep)
 				     "Failed to spawn: %s, stdout:%s, stderr:%s", error_local->message, stdout, stderr);
 		g_error_free (error_local);
 		dbus_g_method_return_error (sleep->context, error);
+		g_error_free (error);
 		goto out;
 	}
 
 	/* emit signal for session components */
-	egg_debug ("emitting resuming");
+	g_debug ("emitting resuming");
 	g_signal_emit (daemon, signals[SIGNAL_RESUMING], 0);
 
 	/* reset the about-to-sleep logic */
@@ -424,7 +428,7 @@ up_daemon_deferred_sleep (UpDaemon *daemon, const gchar *command, DBusGMethodInv
 
 	/* we didn't use AboutToSleep() so send the signal for clients now */
 	if (!priv->sent_sleeping_signal) {
-		egg_debug ("no AboutToSleep(), so emitting ::Sleeping()");
+		g_debug ("no AboutToSleep(), so emitting ::Sleeping()");
 		g_signal_emit (daemon, signals[SIGNAL_SLEEPING], 0);
 		priv->about_to_sleep_id = g_timeout_add (priv->conf_sleep_timeout,
 							 (GSourceFunc) up_daemon_deferred_sleep_cb, sleep);
@@ -436,7 +440,7 @@ up_daemon_deferred_sleep (UpDaemon *daemon, const gchar *command, DBusGMethodInv
 
 	/* about to sleep */
 	elapsed = 1000.0f * g_timer_elapsed (priv->about_to_sleep_timer, NULL);
-	egg_debug ("between AboutToSleep() and %s was %fms", sleep->command, elapsed);
+	g_debug ("between AboutToSleep() and %s was %fms", sleep->command, elapsed);
 	if (elapsed < priv->conf_sleep_timeout) {
 		/* we have to wait for the difference in time */
 		priv->about_to_sleep_id = g_timeout_add (priv->conf_sleep_timeout - elapsed,
@@ -470,6 +474,7 @@ up_daemon_suspend (UpDaemon *daemon, DBusGMethodInvocation *context)
 				     UP_DAEMON_ERROR_GENERAL,
 				     "No kernel support");
 		dbus_g_method_return_error (context, error);
+		g_error_free (error);
 		goto out;
 	}
 
@@ -486,6 +491,7 @@ up_daemon_suspend (UpDaemon *daemon, DBusGMethodInvocation *context)
 				     UP_DAEMON_ERROR_GENERAL,
 				     "Sleep has already been requested and is pending");
 		dbus_g_method_return_error (context, error);
+		g_error_free (error);
 		goto out;
 	}
 
@@ -507,13 +513,21 @@ up_daemon_suspend_allowed (UpDaemon *daemon, DBusGMethodInvocation *context)
 	gboolean ret;
 	PolkitSubject *subject = NULL;
 	UpDaemonPrivate *priv = daemon->priv;
+	GError *error;
 
 	subject = up_polkit_get_subject (priv->polkit, context);
 	if (subject == NULL)
 		goto out;
 
-	ret = up_polkit_is_allowed (priv->polkit, subject, "org.freedesktop.upower.suspend", context);
-	dbus_g_method_return (context, ret);
+	error = NULL;
+	ret = up_polkit_is_allowed (priv->polkit, subject, "org.freedesktop.upower.suspend", &error);
+	if (error) {
+		dbus_g_method_return_error (context, error);
+		g_error_free (error);
+	}
+	else {
+		dbus_g_method_return (context, ret);
+	}
 
 out:
 	if (subject != NULL)
@@ -535,10 +549,10 @@ up_daemon_check_hibernate_swap (UpDaemon *daemon)
 	if (daemon->priv->kernel_can_hibernate) {
 		waterline = up_backend_get_used_swap (daemon->priv->backend);
 		if (waterline < UP_DAEMON_SWAP_WATERLINE) {
-			egg_debug ("enough swap to for hibernate");
+			g_debug ("enough swap to for hibernate");
 			return TRUE;
 		} else {
-			egg_debug ("not enough swap to hibernate");
+			g_debug ("not enough swap to hibernate");
 			return FALSE;
 		}
 	}
@@ -563,6 +577,7 @@ up_daemon_hibernate (UpDaemon *daemon, DBusGMethodInvocation *context)
 				     UP_DAEMON_ERROR_GENERAL,
 				     "No kernel support");
 		dbus_g_method_return_error (context, error);
+		g_error_free (error);
 		goto out;
 	}
 
@@ -572,6 +587,7 @@ up_daemon_hibernate (UpDaemon *daemon, DBusGMethodInvocation *context)
 				     UP_DAEMON_ERROR_GENERAL,
 				     "Not enough swap space");
 		dbus_g_method_return_error (context, error);
+		g_error_free (error);
 		goto out;
 	}
 
@@ -582,6 +598,7 @@ up_daemon_hibernate (UpDaemon *daemon, DBusGMethodInvocation *context)
 				     UP_DAEMON_ERROR_GENERAL,
 				     "Swap space is encrypted, use AllowHibernateEncryptedSwap to override");
 		dbus_g_method_return_error (context, error);
+		g_error_free (error);
 		goto out;
 	}
 
@@ -598,6 +615,7 @@ up_daemon_hibernate (UpDaemon *daemon, DBusGMethodInvocation *context)
 				     UP_DAEMON_ERROR_GENERAL,
 				     "Sleep has already been requested and is pending");
 		dbus_g_method_return_error (context, error);
+		g_error_free (error);
 		goto out;
 	}
 
@@ -619,13 +637,21 @@ up_daemon_hibernate_allowed (UpDaemon *daemon, DBusGMethodInvocation *context)
 	gboolean ret;
 	PolkitSubject *subject = NULL;
 	UpDaemonPrivate *priv = daemon->priv;
+	GError *error;
 
 	subject = up_polkit_get_subject (priv->polkit, context);
 	if (subject == NULL)
 		goto out;
 
-	ret = up_polkit_is_allowed (priv->polkit, subject, "org.freedesktop.upower.hibernate", context);
-	dbus_g_method_return (context, ret);
+	error = NULL;
+	ret = up_polkit_is_allowed (priv->polkit, subject, "org.freedesktop.upower.hibernate", &error);
+	if (error) {
+		dbus_g_method_return_error (context, error);
+		g_error_free (error);
+	}
+	else {
+		dbus_g_method_return (context, ret);
+	}
 
 out:
 	if (subject != NULL)
@@ -683,19 +709,19 @@ up_daemon_startup (UpDaemon *daemon)
 	/* register on bus */
 	ret = up_daemon_register_power_daemon (daemon);
 	if (!ret) {
-		egg_warning ("failed to register");
+		g_warning ("failed to register");
 		goto out;
 	}
 
 	/* stop signals and callbacks */
-	egg_debug ("daemon now coldplug");
+	g_debug ("daemon now coldplug");
 	g_object_freeze_notify (G_OBJECT(daemon));
 	priv->during_coldplug = TRUE;
 
 	/* coldplug backend backend */
 	ret = up_backend_coldplug (priv->backend, daemon);
 	if (!ret) {
-		egg_warning ("failed to coldplug backend");
+		g_warning ("failed to coldplug backend");
 		goto out;
 	}
 
@@ -709,7 +735,7 @@ up_daemon_startup (UpDaemon *daemon)
 	/* start signals and callbacks */
 	g_object_thaw_notify (G_OBJECT(daemon));
 	priv->during_coldplug = FALSE;
-	egg_debug ("daemon now not coldplug");
+	g_debug ("daemon now not coldplug");
 
 	/* set power policy */
 	up_daemon_set_powersave (daemon, priv->on_battery);
@@ -733,11 +759,23 @@ void
 up_daemon_set_lid_is_closed (UpDaemon *daemon, gboolean lid_is_closed)
 {
 	UpDaemonPrivate *priv = daemon->priv;
-	egg_debug ("lid_is_closed = %s", lid_is_closed ? "yes" : "no");
+	g_debug ("lid_is_closed = %s", lid_is_closed ? "yes" : "no");
 	priv->lid_is_closed = lid_is_closed;
 	g_object_notify (G_OBJECT (daemon), "lid-is-closed");
 }
 
+/**
+ * up_daemon_set_lid_force_sleep:
+ **/
+void
+up_daemon_set_lid_force_sleep (UpDaemon *daemon, gboolean lid_force_sleep)
+{
+	UpDaemonPrivate *priv = daemon->priv;
+	g_debug ("lid_force_sleep = %s", lid_force_sleep ? "yes" : "no");
+	priv->lid_force_sleep = lid_force_sleep;
+	g_object_notify (G_OBJECT (daemon), "lid-enforce-sleep");
+}
+
 /**
  * up_daemon_set_lid_is_present:
  **/
@@ -745,11 +783,23 @@ void
 up_daemon_set_lid_is_present (UpDaemon *daemon, gboolean lid_is_present)
 {
 	UpDaemonPrivate *priv = daemon->priv;
-	egg_debug ("lid_is_present = %s", lid_is_present ? "yes" : "no");
+	g_debug ("lid_is_present = %s", lid_is_present ? "yes" : "no");
 	priv->lid_is_present = lid_is_present;
 	g_object_notify (G_OBJECT (daemon), "lid-is-present");
 }
 
+/**
+ * up_daemon_set_is_docked:
+ **/
+void
+up_daemon_set_is_docked (UpDaemon *daemon, gboolean is_docked)
+{
+	UpDaemonPrivate *priv = daemon->priv;
+	g_debug ("is_docked = %s", is_docked ? "yes" : "no");
+	priv->is_docked = is_docked;
+	g_object_notify (G_OBJECT (daemon), "is-docked");
+}
+
 /**
  * up_daemon_set_on_battery:
  **/
@@ -757,7 +807,7 @@ void
 up_daemon_set_on_battery (UpDaemon *daemon, gboolean on_battery)
 {
 	UpDaemonPrivate *priv = daemon->priv;
-	egg_debug ("on_battery = %s", on_battery ? "yes" : "no");
+	g_debug ("on_battery = %s", on_battery ? "yes" : "no");
 	priv->on_battery = on_battery;
 	g_object_notify (G_OBJECT (daemon), "on-battery");
 }
@@ -769,7 +819,7 @@ void
 up_daemon_set_on_low_battery (UpDaemon *daemon, gboolean on_low_battery)
 {
 	UpDaemonPrivate *priv = daemon->priv;
-	egg_debug ("on_low_battery = %s", on_low_battery ? "yes" : "no");
+	g_debug ("on_low_battery = %s", on_low_battery ? "yes" : "no");
 	priv->on_low_battery = on_low_battery;
 	g_object_notify (G_OBJECT (daemon), "on-low-battery");
 }
@@ -788,7 +838,7 @@ up_daemon_refresh_battery_devices_cb (UpDaemon *daemon)
 		return FALSE;
 	}
 
-	egg_debug ("doing the delayed refresh (%i)", priv->battery_poll_count);
+	g_debug ("doing the delayed refresh (%i)", priv->battery_poll_count);
 	up_daemon_refresh_battery_devices (daemon);
 
 	/* keep going until none left to do */
@@ -855,11 +905,11 @@ up_daemon_device_changed_cb (UpDevice *device, UpDaemon *daemon)
 	/* emit */
 	if (!priv->during_coldplug) {
 		object_path = up_device_get_object_path (device);
-		egg_debug ("emitting device-changed: %s", object_path);
+		g_debug ("emitting device-changed: %s", object_path);
 
 		/* don't crash the session */
 		if (object_path == NULL) {
-			egg_warning ("INTERNAL STATE CORRUPT: not sending NULL, device:%p", device);
+			g_warning ("INTERNAL STATE CORRUPT: not sending NULL, device:%p", device);
 			return;
 		}
 		g_signal_emit (daemon, signals[SIGNAL_DEVICE_CHANGED], 0, object_path);
@@ -897,11 +947,11 @@ up_daemon_device_added_cb (UpBackend *backend, GObject *native, UpDevice *device
 	/* emit */
 	if (!priv->during_coldplug) {
 		object_path = up_device_get_object_path (device);
-		egg_debug ("emitting added: %s (during coldplug %i)", object_path, priv->during_coldplug);
+		g_debug ("emitting added: %s (during coldplug %i)", object_path, priv->during_coldplug);
 
 		/* don't crash the session */
 		if (object_path == NULL) {
-			egg_warning ("INTERNAL STATE CORRUPT: not sending NULL, native:%p, device:%p", native, device);
+			g_warning ("INTERNAL STATE CORRUPT: not sending NULL, native:%p, device:%p", native, device);
 			return;
 		}
 		g_signal_emit (daemon, signals[SIGNAL_DEVICE_ADDED], 0, object_path);
@@ -935,11 +985,11 @@ up_daemon_device_removed_cb (UpBackend *backend, GObject *native, UpDevice *devi
 	/* emit */
 	if (!priv->during_coldplug) {
 		object_path = up_device_get_object_path (device);
-		egg_debug ("emitting device-removed: %s", object_path);
+		g_debug ("emitting device-removed: %s", object_path);
 
 		/* don't crash the session */
 		if (object_path == NULL) {
-			egg_warning ("INTERNAL STATE CORRUPT: not sending NULL, native:%p, device:%p", native, device);
+			g_warning ("INTERNAL STATE CORRUPT: not sending NULL, native:%p, device:%p", native, device);
 			return;
 		}
 		g_signal_emit (daemon, signals[SIGNAL_DEVICE_REMOVED], 0, object_path);
@@ -959,7 +1009,7 @@ up_daemon_properties_changed_cb (GObject *object, GParamSpec *pspec, UpDaemon *d
 
 	/* emit */
 	if (!daemon->priv->during_coldplug) {
-		egg_debug ("emitting changed");
+		g_debug ("emitting changed");
 		g_signal_emit (daemon, signals[SIGNAL_CHANGED], 0);
 	}
 }
@@ -973,10 +1023,13 @@ up_daemon_init (UpDaemon *daemon)
 	gboolean ret;
 	GError *error = NULL;
 	GKeyFile *file;
+	const gchar *filename_self_test;
+	gchar *filename;
 
 	daemon->priv = UP_DAEMON_GET_PRIVATE (daemon);
 	daemon->priv->polkit = up_polkit_new ();
 	daemon->priv->lid_is_present = FALSE;
+	daemon->priv->is_docked = FALSE;
 	daemon->priv->lid_is_closed = FALSE;
 	daemon->priv->kernel_can_suspend = FALSE;
 	daemon->priv->kernel_can_hibernate = FALSE;
@@ -994,17 +1047,25 @@ up_daemon_init (UpDaemon *daemon)
 
 	/* load some values from the config file */
 	file = g_key_file_new ();
-	ret = g_key_file_load_from_file (file, PACKAGE_SYSCONF_DIR "/UPower/UPower.conf", G_KEY_FILE_NONE, &error);
+	filename_self_test = g_getenv ("UPOWER_CONF_FILE_NAME");
+	if (filename_self_test != NULL) {
+		g_debug ("using %s as the self test conf file", filename_self_test);
+		filename = g_strdup (filename_self_test);
+	} else {
+		filename = g_build_filename (PACKAGE_SYSCONF_DIR,"UPower", "UPower.conf", NULL);
+	}
+	ret = g_key_file_load_from_file (file, filename, G_KEY_FILE_NONE, &error);
 	if (ret) {
 		daemon->priv->conf_sleep_timeout =
 			g_key_file_get_integer (file, "UPower", "SleepTimeout", NULL);
 		daemon->priv->conf_allow_hibernate_encrypted_swap =
 			g_key_file_get_boolean (file, "UPower", "AllowHibernateEncryptedSwap", NULL);
 	} else {
-		egg_warning ("failed to load config file: %s", error->message);
+		g_warning ("failed to load config file %s: %s", filename, error->message);
 		g_error_free (error);
 	}
 	g_key_file_free (file);
+	g_free (filename);
 
 	daemon->priv->backend = up_backend_new ();
 	g_signal_connect (daemon->priv->backend, "device-added",
@@ -1103,6 +1164,12 @@ up_daemon_get_property (GObject *object, guint prop_id, GValue *value, GParamSpe
 	case PROP_LID_IS_PRESENT:
 		g_value_set_boolean (value, priv->lid_is_present);
 		break;
+	case PROP_LID_FORCE_SLEEP:
+		g_value_set_boolean (value, priv->lid_force_sleep);
+		break;
+	case PROP_IS_DOCKED:
+		g_value_set_boolean (value, priv->is_docked);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -1199,6 +1266,22 @@ up_daemon_class_init (UpDaemonClass *klass)
 							       FALSE,
 							       G_PARAM_READABLE));
 
+	g_object_class_install_property (object_class,
+					 PROP_LID_FORCE_SLEEP,
+					 g_param_spec_boolean ("lid-force-sleep",
+							       "Enforce sleep on lid close",
+							       "If this computer has to sleep on lid close",
+							       FALSE,
+							       G_PARAM_READABLE));
+
+	g_object_class_install_property (object_class,
+					 PROP_IS_DOCKED,
+					 g_param_spec_boolean ("is-docked",
+							       "Is docked",
+							       "If this computer is docked",
+							       FALSE,
+							       G_PARAM_READABLE));
+
 	g_object_class_install_property (object_class,
 					 PROP_CAN_SUSPEND,
 					 g_param_spec_boolean ("can-suspend",
